@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2014-2015 Sebastian Kügler <sebas@kde.org>                             *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2014-2015 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include <QCoreApplication>
 #include <QCryptographicHash>
@@ -127,7 +115,7 @@ void testWaylandBackend::verifyScreen()
 void testWaylandBackend::verifyOutputs()
 {
     bool primaryFound = false;
-    Q_FOREACH (const KScreen::OutputPtr op, m_config->outputs()) {
+    for (const KScreen::OutputPtr op : m_config->outputs()) {
         if (op->isPrimary()) {
             primaryFound = true;
         }
@@ -142,7 +130,7 @@ void testWaylandBackend::verifyOutputs()
     QVERIFY(primary->isConnected());
 
     QList<int> ids;
-    Q_FOREACH (const auto &output, m_config->outputs()) {
+    for (const auto &output : m_config->outputs()) {
         QVERIFY(!output->name().isEmpty());
         QVERIFY(output->id() > -1);
         QVERIFY(output->isConnected());
@@ -163,8 +151,8 @@ void testWaylandBackend::verifyModes()
     QVERIFY(primary);
     QVERIFY(primary->modes().count() > 0);
 
-    Q_FOREACH (const auto &output, m_config->outputs()) {
-        Q_FOREACH (auto mode, output->modes()) {
+    for (const auto &output : m_config->outputs()) {
+        for (const auto &mode : output->modes()) {
             QVERIFY(!mode->name().isEmpty());
             QVERIFY(mode->refreshRate() > 0);
             QVERIFY(mode->size().isValid());
@@ -175,7 +163,7 @@ void testWaylandBackend::verifyModes()
 void testWaylandBackend::verifyIds()
 {
     QList<quint32> ids;
-    Q_FOREACH (const auto &output, m_config->outputs()) {
+    for (const auto &output : m_config->outputs()) {
         QVERIFY(ids.contains(output->id()) == false);
         QVERIFY(output->id() > 0);
         ids << output->id();
