@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2012 - 2014  Daniel Vrátil <dvratil@redhat.com>                        *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2012-2014 Daniel Vrátil <dvratil@redhat.com>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "configmonitor.h"
 #include "abstractbackend.h"
@@ -111,7 +99,8 @@ void ConfigMonitor::Private::backendConfigChanged(const QVariantMap &configMap)
         return;
     }
 
-    Q_FOREACH (OutputPtr output, newConfig->connectedOutputs()) {
+    const auto connectedOutputs = newConfig->connectedOutputs();
+    for (const OutputPtr &output : connectedOutputs) {
         if (!output->edid() && output->isConnected()) {
             QDBusPendingReply<QByteArray> reply = mBackend->getEdid(output->id());
             mPendingEDIDRequests[newConfig].append(output->id());
